@@ -10,7 +10,8 @@ assert.eq( 0, m.getDBs().totalSize );
 
 m.getDB( baseName ).createCollection( baseName + "1" );
 
-expectedMB = 100;
+// Windows does not currently use preallocation
+expectedMB = ( _isWindows() ? 70 : 100 );
 if ( m.getDB( baseName ).serverBits() < 64 )
     expectedMB /= 4;
 
