@@ -2,7 +2,9 @@
 
 summary = "";
 
-s = new ShardingTest( "shard6" , 2 , 0 , 2 );
+s = new ShardingTest( "shard6" , 2 , 0 , 2, { separateConfig : true } );
+
+s.config.settings.update( { _id: "balancer" }, { $set : { stopped: true } } , true );
 
 s.adminCommand( { enablesharding : "test" } );
 s.adminCommand( { shardcollection : "test.data" , key : { num : 1 } } );
@@ -18,6 +20,7 @@ function poolStats( where ){
         msg += z.created + " ";
         total += z.created
     }
+    printjson( x );
     print( "****\n" + msg + "\n*****" )
     summary += msg + "\n";
     return total
