@@ -664,7 +664,7 @@ namespace mongo {
         }
 
         void State::bailFromJS() {
-            log(1) << "M/R: Switching from JS mode to mixed mode" << endl;
+            LOG(1) << "M/R: Switching from JS mode to mixed mode" << endl;
 
             // reduce and reemit into c++
             switchMode(false);
@@ -768,10 +768,12 @@ namespace mongo {
             verify( pm == op->setMessage( "m/r: (3/3) final reduce to collection" , _safeCount( _db, _config.incLong, BSONObj(), QueryOption_SlaveOk ) ) );
 
             shared_ptr<Cursor> temp =
-            NamespaceDetailsTransient::bestGuessCursor( _config.incLong.c_str() , BSONObj() ,
-                                                       sortKey );
-            auto_ptr<ClientCursor> cursor( new ClientCursor( QueryOption_NoCursorTimeout , temp , _config.incLong.c_str() ) );
-
+            NamespaceDetailsTransient::bestGuessCursor(_config.incLong.c_str(),
+                                                       BSONObj(),
+                                                       sortKey);
+            ClientCursor::Holder cursor(new ClientCursor(QueryOption_NoCursorTimeout,
+                                                         temp,
+                                                         _config.incLong.c_str()));
             // iterate over all sorted objects
             while ( cursor->ok() ) {
                 BSONObj o = cursor->current().getOwned();
@@ -784,7 +786,6 @@ namespace mongo {
                     all.push_back( o );
                     if ( pm->hits() % 100 == 0 ) {
                         if ( ! cursor->yield() ) {
-                            cursor.release();
                             break;
                         }
                         killCurrentOp.checkForInterrupt();
@@ -800,7 +801,6 @@ namespace mongo {
                 }
                 catch (...) {
                     yield.relock();
-                    cursor.release();
                     throw;
                 }
 
@@ -809,20 +809,16 @@ namespace mongo {
                 all.push_back( o );
 
                 if ( ! yield.stillOk() ) {
-                    cursor.release();
                     break;
                 }
 
                 killCurrentOp.checkForInterrupt();
             }
-            
-            // we need to release here since we temp release below
-            cursor.release();
 
             {
                 dbtempreleasecond tl;
                 if ( ! tl.unlocked() )
-                    log( LL_WARNING ) << "map/reduce can't temp release" << endl;
+                    LOG( LL_WARNING ) << "map/reduce can't temp release" << endl;
                 // reduce and finalize last array
                 finalReduce( all );
             }
@@ -932,7 +928,7 @@ namespace mongo {
                     // reduce now to lower mem usage
                     Timer t;
                     _scope->invoke(_reduceAll, 0, 0, 0, true);
-                    log(1) << "  MR - did reduceAll: keys=" << keyCt << " dups=" << dupCt << " newKeys=" << _scope->getNumberInt("_keyCt") << " time=" << t.millis() << "ms" << endl;
+                    LOG(1) << "  MR - did reduceAll: keys=" << keyCt << " dups=" << dupCt << " newKeys=" << _scope->getNumberInt("_keyCt") << " time=" << t.millis() << "ms" << endl;
                     return;
                 }
             }
@@ -945,12 +941,12 @@ namespace mongo {
                 long oldSize = _size;
                 Timer t;
                 reduceInMemory();
-                log(1) << "  MR - did reduceInMemory: size=" << oldSize << " dups=" << _dupCount << " newSize=" << _size << " time=" << t.millis() << "ms" << endl;
+                LOG(1) << "  MR - did reduceInMemory: size=" << oldSize << " dups=" << _dupCount << " newSize=" << _size << " time=" << t.millis() << "ms" << endl;
 
                 // if size is still high, or values are not reducing well, dump
                 if ( _onDisk && (_size > _config.maxInMemSize || _size > oldSize / 2) ) {
                     dumpToInc();
-                    log(1) << "  MR - dumping to db" << endl;
+                    LOG(1) << "  MR - dumping to db" << endl;
                 }
             }
         }
@@ -1020,7 +1016,7 @@ namespace mongo {
 
                 Config config( dbname , cmd );
 
-                log(1) << "mr ns: " << config.ns << endl;
+                LOG(1) << "mr ns: " << config.ns << endl;
 
                 uassert( 16149 , "cannot run map reduce without the js engine", globalScriptEngine );
 
@@ -1091,7 +1087,9 @@ namespace mongo {
                         // obtain full cursor on data to apply mr to
                         shared_ptr<Cursor> temp = NamespaceDetailsTransient::getCursor( config.ns.c_str(), config.filter, config.sort );
                         uassert( 16052, str::stream() << "could not create cursor over " << config.ns << " for query : " << config.filter << " sort : " << config.sort, temp.get() );
-                        auto_ptr<ClientCursor> cursor( new ClientCursor( QueryOption_NoCursorTimeout , temp , config.ns.c_str() ) );
+                        ClientCursor::Holder cursor(new ClientCursor(QueryOption_NoCursorTimeout,
+                                                                     temp,
+                                                                     config.ns.c_str()));
                         uassert( 16053, str::stream() << "could not create client cursor over " << config.ns << " for query : " << config.filter << " sort : " << config.sort, cursor.get() );
 
                         Timer mt;
@@ -1132,7 +1130,6 @@ namespace mongo {
                                 inReduce += t.micros();
 
                                 if ( ! yield.stillOk() ) {
-                                    cursor.release();
                                     break;
                                 }
 
