@@ -92,6 +92,8 @@ namespace mongo {
                 replset::BackgroundSync::notify();
             }
         }
+
+        OpTime::setLast( ts );
     }
 
     /** given a BSON object, create a new one at dst which is the existing (partial) object
@@ -222,7 +224,7 @@ namespace mongo {
         append_O_Obj(r->data(), partial, obj);
 
         if ( logLevel >= 6 ) {
-            log( 6 ) << "logOp:" << BSONObj::make(r) << endl;
+            LOG( 6 ) << "logOp:" << BSONObj::make(r) << endl;
         }
     }
 
