@@ -691,7 +691,7 @@ namespace UpdateTests {
                 auto_ptr<ModSetState> modSetState = modSet.prepare( obj );
                 ASSERT_FALSE( modSetState->canApplyInPlace() );
                 modSetState->createNewFromMods();
-                ASSERT_EQUALS( BSON( "$set" << BSON( "a" << 3 ) << "$set" << BSON("b" << 2)),
+                ASSERT_EQUALS( BSON( "$set" << BSON( "a" << 3 << "b" << 2)),
                                modSetState->getOpLogRewrite() );
             }
         };
@@ -705,7 +705,7 @@ namespace UpdateTests {
                 auto_ptr<ModSetState> modSetState = modSet.prepare( obj );
                 ASSERT_FALSE( modSetState->canApplyInPlace() );
                 modSetState->createNewFromMods();
-                ASSERT_EQUALS( BSON( "$set" << BSON( "a" << 1 ) << "$set" << BSON("b" << 2)),
+                ASSERT_EQUALS( BSON( "$set" << BSON( "a" << 1 << "b" << 2)),
                                modSetState->getOpLogRewrite() );
             }
         };
@@ -861,7 +861,7 @@ namespace UpdateTests {
                 auto_ptr<ModSetState> modSetState = modSet.prepare( obj );
                 ASSERT_FALSE( modSetState->canApplyInPlace() );
                 modSetState->createNewFromMods();
-                ASSERT_EQUALS( fromjson( "{ $set:{ 'a.b':[ 1 ] }, $set:{ 'a.c':[ 1 ] } }" ),
+                ASSERT_EQUALS( fromjson( "{ $set:{ 'a.b':[ 1 ] , 'a.c':[ 1 ] } }" ),
                                modSetState->getOpLogRewrite() );
             }
         };
@@ -1017,7 +1017,7 @@ namespace UpdateTests {
                                 auto_ptr<ModSetState> modSetState = modSet.prepare( obj );
                 ASSERT_FALSE( modSetState->canApplyInPlace() );
                 modSetState->createNewFromMods();
-                ASSERT_EQUALS( BSON( "$unset" << BSON( "a" << 1 ) << "$set" << BSON ( "b" << 100 ) ),
+                ASSERT_EQUALS( BSON( "$set" << BSON( "b" << 100 ) << "$unset" << BSON ( "a" << 1 ) ),
                                modSetState->getOpLogRewrite() );
             }
         };
@@ -1031,7 +1031,7 @@ namespace UpdateTests {
                                 auto_ptr<ModSetState> modSetState = modSet.prepare( obj );
                 ASSERT_FALSE( modSetState->canApplyInPlace() );
                 modSetState->createNewFromMods();
-                ASSERT_EQUALS( BSON( "$unset" << BSON( "a" << 1 ) << "$set" << BSON ( "b" << 100 ) ),
+                ASSERT_EQUALS( BSON( "$set" << BSON( "b" << 100 ) << "$unset" << BSON ( "a" << 1 ) ),
                                modSetState->getOpLogRewrite() );
             }
         };
@@ -1092,6 +1092,31 @@ namespace UpdateTests {
                                modSetState->getOpLogRewrite() );
             }
         };
+
+        class MultiSets {
+        public:
+            void run() {
+                BSONObj obj = BSON( "_id" << 1 << "a" << 1 << "b" << 1 );
+                BSONObj mod = BSON( "$set" << BSON( "a" << 2 << "b" << 2 ) );
+                ModSet modSet( mod );
+                auto_ptr<ModSetState> modSetState = modSet.prepare( obj );
+                ASSERT_TRUE( modSetState->canApplyInPlace() );
+                ASSERT_EQUALS( mod, modSetState->getOpLogRewrite() );
+            }
+        };
+
+        class CreateNewFromQueryExcludeNot {
+        public:
+            void run() {
+                BSONObj querySpec = BSON( "a" << BSON( "$not" << BSON( "$lt" << 1 ) ) );
+                BSONObj modSpec = BSON( "$set" << BSON( "b" << 1 ) );
+                ModSet modSet( modSpec );
+
+                // Because a $not operator is applied to the 'a' field, the 'a' field is excluded
+                // from the resulting document.
+                ASSERT_EQUALS( BSON( "b" << 1 ), modSet.createNewFromQuery( querySpec ) );
+            }
+        };
     };
 
     namespace basic {
@@ -1421,6 +1446,7 @@ namespace UpdateTests {
             // add< ModSetTests::BitRewriteNonExistingField >();
             add< ModSetTests::SetIsNotRewritten >();
             add< ModSetTests::UnsetIsNotRewritten >();
+            add< ModSetTests::MultiSets >();
 
             add< basic::inc1 >();
             add< basic::inc2 >();
