@@ -768,9 +768,11 @@ namespace mongo {
         vector<BSONObj> res;
         for ( unsigned i=0; i<_config.size(); i++ ) {
             BSONObj x;
+
+            scoped_ptr<ScopedDbConnection> conn;
+
             try {
-                scoped_ptr<ScopedDbConnection> conn(
-                        ScopedDbConnection::getInternalScopedDbConnection( _config[i], 30.0 ) );
+                conn.reset( ScopedDbConnection::getInternalScopedDbConnection( _config[i], 30.0 ) );
 
                 // check auth
                 conn->get()->update("config.foo.bar", BSONObj(), BSON("x" << 1));
@@ -791,6 +793,9 @@ namespace mongo {
                 conn->done();
             }
             catch ( const DBException& e ) {
+                if (conn) {
+                    conn->kill();
+                }
 
                 // We need to catch DBExceptions b/c sometimes we throw them
                 // instead of socket exceptions when findN fails
@@ -809,7 +814,7 @@ namespace mongo {
         }
 
         if ( up == 1 ) {
-            log( LL_WARNING ) << "only 1 config server reachable, continuing" << endl;
+            LOG( LL_WARNING ) << "only 1 config server reachable, continuing" << endl;
             return true;
         }
 
@@ -829,7 +834,7 @@ namespace mongo {
 
             stringstream ss;
             ss << "config servers " << _config[firstGood] << " and " << _config[i] << " differ";
-            log( LL_WARNING ) << ss.str();
+            LOG( LL_WARNING ) << ss.str() << endl;
             if ( tries <= 1 ) {
                 ss << "\n" << c1 << "\t" << c2 << "\n" << d1 << "\t" << d2;
                 errmsg = ss.str();
@@ -849,7 +854,7 @@ namespace mongo {
         if ( checkConsistency ) {
             string errmsg;
             if ( ! checkConfigServersConsistent( errmsg ) ) {
-                log( LL_ERROR ) << "config servers not in sync! " << errmsg << warnings;
+                LOG( LL_ERROR ) << "config servers not in sync! " << errmsg << warnings;
                 return false;
             }
         }
@@ -1030,7 +1035,7 @@ namespace mongo {
         try {
             Shard s = Shard::lookupRSName(monitor->getName());
             if (s == Shard::EMPTY) {
-                log(1) << "replicaSetChange: shard not found for set: " << monitor->getServerAddress() << endl;
+                LOG(1) << "replicaSetChange: shard not found for set: " << monitor->getServerAddress() << endl;
                 return;
             }
             scoped_ptr<ScopedDbConnection> conn( ScopedDbConnection::getInternalScopedDbConnection(
