@@ -866,8 +866,7 @@ namespace mongo {
                     return false;
                 }
                 string configdb = cmdObj["configdb"].String();
-                shardingState.enable( configdb );
-                configServer.init( configdb );
+                ShardingState::initialize(configdb);
             }
 
             MoveTimingHelper timing( "from" , ns , min , max , 6 /* steps */ , errmsg );
@@ -1072,7 +1071,7 @@ namespace mongo {
 
                 conn->done();
 
-                log(0) << "moveChunk data transfer progress: " << res << " my mem used: " << migrateFromStatus.mbUsed() << migrateLog;
+                LOG(0) << "moveChunk data transfer progress: " << res << " my mem used: " << migrateFromStatus.mbUsed() << migrateLog;
 
                 if ( ! ok || res["state"].String() == "fail" ) {
                     warning() << "moveChunk error transferring data caused migration abort: " << res << migrateLog;
@@ -1281,7 +1280,8 @@ namespace mongo {
                 try {
                     scoped_ptr<ScopedDbConnection> conn(
                             ScopedDbConnection::getInternalScopedDbConnection(
-                                    shardingState.getConfigServer() ) );
+                                    shardingState.getConfigServer(),
+                                    10.0 ) );
                     ok = conn->get()->runCommand( "config" , cmd , cmdResult );
                     conn->done();
                 }
@@ -1308,7 +1308,8 @@ namespace mongo {
                     try {
                         scoped_ptr<ScopedDbConnection> conn(
                                 ScopedDbConnection::getInternalScopedDbConnection(
-                                        shardingState.getConfigServer() ) );
+                                        shardingState.getConfigServer(),
+                                        10.0 ) );
 
                         // look for the chunk in this shard whose version got bumped
                         // we assume that if that mod made it to the config, the applyOps was successful
@@ -1879,7 +1880,7 @@ namespace mongo {
             }
 
             if ( ! configServer.ok() )
-                configServer.init( cmdObj["configServer"].String() );
+                ShardingState::initialize(cmdObj["configServer"].String());
 
             migrateStatus.prepare();
 
