@@ -523,8 +523,7 @@ namespace mongo {
                     return false;
                 }
                 string configdb = cmdObj["configdb"].String();
-                shardingState.enable( configdb );
-                configServer.init( configdb );
+                ShardingState::initialize(configdb);
             }
 
             Shard myShard( from );
@@ -584,7 +583,7 @@ namespace mongo {
                     result.append( "requestedMin" , min );
                     result.append( "requestedMax" , max );
 
-                    log( LL_WARNING ) << "aborted split because " << errmsg << ": " << min << "->" << max
+                    LOG( LL_WARNING ) << "aborted split because " << errmsg << ": " << min << "->" << max
                                       << " is now " << currMin << "->" << currMax << endl;
                     return false;
                 }
@@ -594,7 +593,7 @@ namespace mongo {
                     result.append( "from" , myShard.getName() );
                     result.append( "official" , shard );
 
-                    log( LL_WARNING ) << "aborted split because " << errmsg << ": chunk is at " << shard
+                    LOG( LL_WARNING ) << "aborted split because " << errmsg << ": chunk is at " << shard
                                       << " and not at " << myShard.getName() << endl;
                     return false;
                 }
@@ -604,7 +603,7 @@ namespace mongo {
                     maxVersion.addToBSON( result, "officialVersion" );
                     shardingState.getVersion( ns ).addToBSON( result, "myVersion" );
 
-                    log( LL_WARNING ) << "aborted split because " << errmsg << ": official " << maxVersion
+                    LOG( LL_WARNING ) << "aborted split because " << errmsg << ": official " << maxVersion
                                       << " mine: " << shardingState.getVersion(ns) << endl;
                     return false;
                 }
