@@ -171,7 +171,7 @@ again:
 
                 if ( len == 542393671 ) {
                     // an http GET
-                    log( psock->getLogLevel() ) << "looks like you're trying to access db over http on native driver port.  please add 1000 for webserver" << endl;
+                    LOG( psock->getLogLevel() ) << "looks like you're trying to access db over http on native driver port.  please add 1000 for webserver" << endl;
                     string msg = "You are trying to access MongoDB on the native driver port. For http diagnostic access, add 1000 to the port number\n";
                     stringstream ss;
                     ss << "HTTP/1.0 200 OK\r\nConnection: close\r\nContent-Type: text/plain\r\nContent-Length: " << msg.size() << "\r\n\r\n" << msg;
@@ -179,7 +179,7 @@ again:
                     send( s.c_str(), s.size(), "http" );
                     return false;
                 }
-                log(0) << "recv(): message len " << len << " is too large" << len << endl;
+                LOG(0) << "recv(): message len " << len << " is too large" << len << endl;
                 return false;
             }
 
@@ -201,7 +201,7 @@ again:
 
         }
         catch ( const SocketException & e ) {
-            log(psock->getLogLevel() + (e.shouldPrint() ? 0 : 1) ) << "SocketException: remote: " << remote() << " error: " << e << endl;
+            LOG(psock->getLogLevel() + (e.shouldPrint() ? 0 : 1) ) << "SocketException: remote: " << remote() << " error: " << e << endl;
             m.reset();
             return false;
         }
